import setuptools

setuptools.setup(
    name="focus-xp-9588",
    version="0.0.1",
    author="xp9588",
    author_email="958876660@qq.com",
    description="focus package",
    url="https://github.com/pxp511/focus",
    packages=setuptools.find_packages(),
    platforms='any',
    license='',
    zip_safe=False,
    
)